@@ -12,7 +12,7 @@ use vars qw($conn);
 use DBI;
 use strict;
 
-my $VERSION = '1.0';
+my $VERSION = '1.1.1';
 
 # Inicia conexao
 sub new {
@@ -28,6 +28,7 @@ sub new {
 		bless {
 			conn => $conn,
 			type => $vars->{type},
+			error => undef,
 		}, $self;
 	}
 
@@ -45,7 +46,7 @@ sub return {
 	eval { $c = $self->{conn}->prepare($q); };
 
 	# Verifica se conseguiu executar a query
-	eval { $c->execute } or print DBI::errstr;
+	eval { $c->execute } or die DBI::errstr;
 	
 	# Retorna em formato array
 	if ($t eq "array") {
@@ -79,7 +80,7 @@ sub do {
 	$self->{conn}->do($q);
 	
 	if (DBI::errstr) {
-		print DBI::errstr;
+		$self->{error} = DBI::errstr;
 		return 0;
 	}
 	
@@ -118,6 +119,12 @@ sub insertid {
 	if ($self->{type} eq "mysql") { $self->{conn}->{mysql_insertid}; }
 }
 
+# retorn erro
+sub error {
+	my ($self) = @_;
+	return $self->{error};
+}
+
 1;
 
 =head1 NAME
@@ -228,7 +235,7 @@ MySQL easy access
 =head1 AUTHOR
 
    Udlei D. R. Nattis
-	nattis@anankeit.com.br
+   nattis@anankeit.com.br
    http://www.nobol.com.br
    http://www.anankeit.com.br
 
